==> gnome-builder-3.16.1.tar.xz: gnome-builder-3.16.1/libide/clang/ide-clang-private.h <==
/* ide-clang-private.h
 *
 * Copyright (C) 2015 Christian Hergert <christian@hergert.me>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef IDE_CLANG_PRIVATE_H
#define IDE_CLANG_PRIVATE_H

#include <clang-c/Index.h>

#include "ide-types.h"

#include "ide-clang-service.h"
#include "ide-clang-translation-unit.h"
#include "ide-highlight-index.h"

G_BEGIN_DECLS

IdeClangTranslationUnit *_ide_clang_translation_unit_new (IdeContext        *context,
                                                          CXTranslationUnit  tu,
                                                          GFile             *file,
                                                          IdeHighlightIndex *index,
                                                          gint64             sequence);
void                     _ide_clang_dispose_string       (CXString          *str);

G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (CXString, _ide_clang_dispose_string)

G_END_DECLS

#endif /* IDE_CLANG_PRIVATE_H */

==> gnome-builder-3.16.3.tar.xz: gnome-builder-3.16.3/libide/clang/ide-clang-private.h <==
/* ide-clang-private.h
 *
 * Copyright (C) 2015 Christian Hergert <christian@hergert.me>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef IDE_CLANG_PRIVATE_H
#define IDE_CLANG_PRIVATE_H

#include <clang-c/Index.h>

#include "ide-types.h"

#include "ide-clang-service.h"
#include "ide-clang-translation-unit.h"
#include "ide-highlight-index.h"

G_BEGIN_DECLS

IdeClangTranslationUnit *_ide_clang_translation_unit_new (IdeContext        *context,
                                                          CXTranslationUnit  tu,
                                                          GFile             *file,
                                                          IdeHighlightIndex *index,
                                                          gint64             serial);
void                     _ide_clang_dispose_string       (CXString          *str);

G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (CXString, _ide_clang_dispose_string)

G_END_DECLS

#endif /* IDE_CLANG_PRIVATE_H */
